<?php

namespace Drupal\cryptophoto\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\cryptophoto\Storage;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;
use Drupal\Core\Url;
use Drupal\Core\Link;

/*
 * CryptoPhoto User List admin page
 */
class CryptoPhotoUserListController extends ControllerBase {
  // request
  private $request;
  // base URL
  private $murl;
  // query parameters (filter + paging)
  private $qparams;

  public function __construct(RequestStack $request) {
    // get request
    $this->request = $request->getCurrentRequest();
    // build base URL
    global $base_url;
    $this->murl = $base_url . \Drupal\Core\Url::fromRoute('cryptophoto.user_list')->toString();

    // initialize query params
    $this->qparams = array(
      'filter' => '',
    );

    // remember filter
    if ($p = $this->request->get('filter')) {
      error_log("Filter = $p");
      $this->qparams['filter'] = $p;
    }

    // remember page
    if ($p = $this->request->get('page')) {
      error_log("Page = $p");
      $this->qparams['page'] = $p;
    }
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('request_stack')
    );
  }

  /*
   * Build CryptoPhoto status and override toggle link
   */
  private function create_link($uid, $param, $cv) {
    $cvs = $cv ? 'Enabled' : 'Disabled';
    $nv = $cv ? 'Disable' : 'Enable';

    $fc = array();
    $fc['cpst'] = array(
      '#type' => 'container'
    );
    $fc['cpst']['status'] = array(
      '#markup' => $cvs
    );
    $fc['cpst']['lws'] = array('#markup' => ' (');
    $fc['cpst']['toggle'] = array(
      '#type' => 'link',
      '#url' => \Drupal\Core\Url::fromUri($this->murl, array(
        'query' => array_merge($this->qparams, array(
          'uid' => $uid,
          $param => 1 -$cv
        ))
      )),
      '#title' => $nv
    );
    $fc['cpst']['lwe'] = array('#markup' => ')');

    return \Drupal::service('renderer')->render($fc);
  }

  /*
   * Build CryptoPhoto user list
   */
  public function cp_user_list() {
    // no cache
    \Drupal::service('page_cache_kill_switch')->trigger();

    $req = $this->request;

    // initialize Cryptophoto storage
    $cps = new \Drupal\cryptophoto\Storage\CryptoPhotoStorage;

    // handle CryptoPhoto status/override
    if ($uid = $req->get('uid')) {
      if (($enabled = $req->get('enabled')) != null) {
        $cps->setStatus($uid, $enabled);
      }
      if (($override = $req->get('override')) != null) {
        $cps->setOverride($uid, $override);
      }
    }

    // build page
    
    // table header
    $header = array(
      'uid' => t('Id'),
      'username' => t('User Name'),
      'email' => t('Email'),
      'cp_status' => t('CryptoPhoto Status'),
      'cp_override' => t('CryptoPhoto Override')
    );
    
    // get users
    $rows = array();
    $users = $cps->getUsers($this->qparams['filter']);

    // prepare table data
    foreach($users as $uid => $data) {
      $rows[] = array(
        'data' => array(
            $uid,
            $data->name,
            $data->mail,
            $this->create_link($uid, 'enabled', $data->enabled),
            $this->create_link($uid, 'override', $data->override)
        )
      );
    }

    // prepare filter
    $build['search'] = array(
      '#type' => 'form',
      '#method' => 'get',
      '#theme_wrappers' => array('form'),
    );

    $fv = $this->qparams['filter'];
    $build['search']['filter'] = array(
      '#name' => 'filter',
      '#type' => 'textfield',
      '#title' => 'Name or Email',
      '#maxlength' => 20,
      '#value' => $fv,
    );

    $build['search']['submit'] = array(
      '#type' => 'submit',
      '#value' => $this->t('Filter'),
      '#button_type' => 'primary',
    );

    $build['vsp'] = array('#markup' => '<br/>');

    // prepare table
    $build['table'] = array(
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $rows,
      '#attributes' => array(
        'id' => 'cp-users-table',
      ),
    );

    // add table pager
    $build['pager'] = array(
      '#type' => 'pager'
    );

    return $build;
  }
}

?>
