<?php

namespace Drupal\cryptophoto\Controller;

require_once("lib/CryptoPhotoUtils.php");

use Drupal\Core\Controller\ControllerBase;
use Drupal\cryptophoto\Storage;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * CryptoPhoto User Preferences
 */
class CryptoPhotoUserPrefController extends ControllerBase {
  public $request;

  public function __construct(RequestStack $request) {
    $this->request = $request;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('request_stack')
    );
  }

  public function cp_page() {
    // no cache
    \Drupal::service('page_cache_kill_switch')->trigger();

    // get request, current user, config
    $req = $this->request->getCurrentRequest();
    $user = \Drupal::currentUser();
    $config = $this->config('cryptophoto.settings');

    // base url
    global $base_url;

    // get CryptoPhoto config
    $privatekey = $config->get('privatekey');
    $publickey = $config->get('publickey');
    $salt = $config->get('salt');
    $server = $config->get('server');

    // test if Cryptophoto is setup
    if ($publickey && $privatekey && $salt && $server) {
      // initialize Storage
      $cpus = new \Drupal\cryptophoto\Storage\CryptoPhotoStorage;

      $enabled = null;

      // handle status toggle
      if (($enabled = $req->get('enabled', null)) != null) {
        $cpus->setStatus($user->id(), $enabled);
      }

      // status not present in request so read ti from database
      if ($enabled === null) {
        $enabled = $cpus->getStatus($user->id());
      }

      // build page
      if (!$enabled) {
        $preferences['status'] = array(
          '#markup' => '<p>CryptoPhoto status: <b>disabled</b>&nbsp;<a href="' . $base_url . '/user/cryptophoto?enabled=1" class="button primary">Enable</a></p>'
        );
      } else {
        // initialize CryptoPhoto
        $cp = new \CryptoPhotoUtils($server, $privatekey, $publickey, md5($salt . $user->id()));

        // start a new session
        $cp->start_session($_SERVER['REMOTE_ADDR']);

        // show the CryptoPhoto token widget
        $preferences['status'] = array(
          '#markup' => '<p>CryptoPhoto status: <b>enabled</b>&nbsp;<a href="' . $base_url . '/user/cryptophoto?enabled=0" class="button primary">Disable</a></p>',
        );
        $preferences['cp_widget'] = array(
          '#id' => 'cp_widget',
          '#markup' => '<div id="cp_widget"></div>',
        );
        $preferences['#attached']['library'][] = 'cryptophoto/add_script';
        $preferences['#attached']['drupalSettings']['cryptophoto']['as_url'] = $cp->get_gen_widget_url();
      }
    } else {
      // CryptoPhoto setup is not complete. Let the user know
      $preferences = array(
        '#markup' => '<p>CryptoPhoto is not configured. Please contact an administrator.</p>',
      );
    } 

    return $preferences;
  }
}

?>
